@@ -6,6 +6,6 @@ def test_download_get():
     "occurrences.download_get - basic test"
     key = "0089857-160910150852091"
     res = occ.download_get(key)
-    assert 'dict' == res.__class__.__name__
+    assert "dict" == res.__class__.__name__
     assert len(res) == 3
-    assert key == res['key']
+    assert key == res["key"]
